--[[ 
Title: LootMyFish
Notes: Enables autolooting when a fishing pole is equipped and disables it afterwards.
Author: Naranja
Version: 1.0
]]--

LootMyFish = {}

function LootMyFish.new()
	local self = {}
	
	--[[ Private variables ]]--
	local frame = nil
	local mainhandSlotId = nil
	local mainhandHasItem = false
	local isAutolooting = false	
	
	--[[ Public variables ]]--
	self.enabled = false
	self.chatColor = "00E0DE55"
	
	--[[ Private methods ]]--
	-- Prints a message to the default chat log
	local function printMessage(msg)
		DEFAULT_CHAT_FRAME:AddMessage("|c" .. self.chatColor .. msg)
	end
	
	-- Toggles autolooting
	local function toggleAutoloot(enable)
		if (enable) then
			printMessage("Autolooting: On")
			SetCVar("autoLootDefault", "1")
			isAutolooting = true
		else
			printMessage("Autolooting: Off")
			SetCVar("autoLootDefault", "0")
			isAutolooting = false			
		end
	end
	
	-- Handles and dispatches all incoming events	
	local function onEvent(frameObj, event, ...)
		-- Show onload message and start addon
		if event == "ADDON_LOADED" then
			local addonName = ...
			if addonName == "LootMyFish" then
				printMessage("LootMyFish Loaded. (/lmf)")
			end
		end
		
		-- Check autoloot CVar when it's loaded
		if event == "VARIABLES_LOADED" then
			autoLootDefault = GetCVar("autoLootDefault")
			if autoLootDefault == "1" then
				isAutolooting = true
			else
				isAutolooting = false
			end
			self.enabled = true
			toggleAutoloot(isAutolooting)
		end

		-- Return when addon is disabled
		if not self.enabled then return end
		
		-- Handle player inventory changed message
		if event == "PLAYER_EQUIPMENT_CHANGED" then
			local slot, mainHandHasItem = ...
			if slot == mainhandSlotId then
				local poleEquipped = IsEquippedItemType("Fishing Poles")
				if poleEquipped and not isAutolooting then
					toggleAutoloot(true)
				elseif not poleEquipped and isAutolooting then
					toggleAutoloot(false)
				end
			end
		end
	end
	
	-- Handle /lmf slashcommand
	local function slashHandler(msg, editbox)
		if type(msg) ~= "string" then return end
		-- enable
		if msg == 'enable' then
			if not self.enabled then
				self.enabled = true
				printMessage("LootMyFish enabled.")
			else
				printMessage("LootMyFish already enabled.")
			end
		-- disable
		elseif msg == 'disable' then
			if self.enabled then
				self.enabled = false
				printMessage("LootMyFish disabled.")
			else
				printMessage("LootMyFish already disabled.")
			end
		-- default
		else
			printMessage("Usage: /lmf [enable | disable]")
		end
	end
	
	
	--[[ Public methods	 ]]--
	-- Initializes lmf on a frame and registers on events
	function self.init(frameName)
		-- Create frame
		frame = CreateFrame("Frame", frameName)
		-- Register events
		frame:RegisterEvent("ADDON_LOADED")
		frame:RegisterEvent("VARIABLES_LOADED")
		frame:RegisterEvent("PLAYER_EQUIPMENT_CHANGED")
		frame:SetScript("OnEvent", onEvent)
		-- Set the mainhand slot id
		mainhandSlotId = GetInventorySlotInfo("MainHandSlot")
		-- Register and assign /lmf slash command
		SLASH_LOOTMYFISH1 = '/lmf'
		SlashCmdList["LOOTMYFISH"] = slashHandler
	end
	
	return self
end

lmf = LootMyFish.new()
lmf.init("LootMyFishFrame")